@@ -1,6 +1,6 @@
 package Net::DNS::RR::MG;
 #
-# $Id: MG.pm,v 2.100 2003/12/13 01:37:05 ctriv Exp $
+# $Id: MG.pm,v 2.101 2004/01/04 04:31:10 ctriv Exp $
 #
 use strict;
 use vars qw(@ISA $VERSION);
@@ -8,15 +8,15 @@ use vars qw(@ISA $VERSION);
 use Net::DNS::Packet;
 
 @ISA     = qw(Net::DNS::RR);
-$VERSION = (qw$Revision: 2.100 $)[1];
+$VERSION = (qw$Revision: 2.101 $)[1];
 
 sub new {
 	my ($class, $self, $data, $offset) = @_;
 
 	if ($self->{"rdlength"} > 0) {
-		my ($mgmname) = Net::DNS::Packet::dn_expand($data, $offset);
-		$self->{"mgmname"} = $mgmname;
+		($self->{"mgmname"}) = Net::DNS::Packet::dn_expand($data, $offset);
 	}
+	
 	return bless $self, $class;
 }
 
@@ -34,9 +34,7 @@ sub new_from_string {
 sub rdatastr {
 	my $self = shift;
 
-	return exists $self->{"mgmname"}
-	       ? "$self->{mgmname}."
-	       : "; no data";
+	return exists $self->{"mgmname"} ? "$self->{mgmname}." : '';
 }
 
 sub rr_rdata {
